@@ -4,9 +4,12 @@ with 'Net::Amazon::EMR::Role::AttrHash';
 use Net::Amazon::EMR::Coercions;
 
 
-has 'InstanceGroupIds' => ( is => 'ro', isa => 'Net::Amazon::EMR::Type::ArrayRefofStr', coerce => 1 );
+has 'InstanceGroupIds' => ( is => 'ro',
+                            isa => 'Net::Amazon::EMR::Type::ArrayRefofConstrainedStr',
+                            coerce => 1 );
 
-has 'JobFlowId' => ( is => 'ro', isa => 'Str' );
+has 'JobFlowId' => ( is => 'ro',
+                     isa => 'Str' );
 
 __PACKAGE__->meta->make_immutable();
 
