@@ -104,6 +104,12 @@ coerce 'Net::Amazon::EMR::Type::ArrayRefofStr'
     => from 'HashRef'
     => via { my $s = $_->{member}; ref($s) eq 'ARRAY' ? $s : [ $s ] };
 
+subtype 'Net::Amazon::EMR::Type::StrStrMap' => as 'HashRef[Str]';
+
+coerce  'Net::Amazon::EMR::Type::StrStrMap'
+  => from 'Undef'
+  => via { {} };
+
 subtype 'Net::Amazon::EMR::Type::ConstrainedStr' => as 'Str' => where { length($_) <= 256 && m/^[\N{U+0020}-\N{U+D7FF}\N{U+E000}-\N{U+FFFD}\r\n\t]*$/ };
 
 subtype 'Net::Amazon::EMR::Type::NonEmptyConstrainedStr' => as 'Str' => where { length($_) <= 256 && m/^[\N{U+0020}-\N{U+D7FF}\N{U+E000}-\N{U+FFFD}\r\n\t]+$/ };
