@@ -4,7 +4,7 @@ with 'Net::Amazon::EMR::Role::AttrHash';
 use Net::Amazon::EMR::Coercions;
 
 has 'Args' => ( is => 'ro', 
-                isa => 'Net::Amazon::EMR::Type::ArrayRefofStr | Undef',
+                isa => 'Net::Amazon::EMR::Type::ArrayRefofLongConstrainedStr',
                 coerce => 1,
  );
 
@@ -15,7 +15,7 @@ has 'MainClass' => ( is => 'ro',
                      isa => 'Str' );
 
 has 'Properties' => ( is => 'ro', 
-                      isa => 'Net::Amazon::EMR::Type::ArrayRefofKeyValue | Undef',
+                      isa => 'Net::Amazon::EMR::Type::ArrayRefofKeyValue',
                       coerce => 1,
     );
 
