@@ -15,7 +15,8 @@ has 'MainClass' => ( is => 'ro',
                      isa => 'Str' );
 
 has 'Properties' => ( is => 'ro', 
-                      isa => 'HashRef'
+                      isa => 'Net::Amazon::EMR::Type::StrStrMap',
+                      coerce => 1,
     );
 
 __PACKAGE__->meta->make_immutable();
