@@ -3,11 +3,18 @@ use Moose;
 with 'Net::Amazon::EMR::Role::AttrHash';
 use Net::Amazon::EMR::Coercions;
 
+has 'EC2InstanceIdsToTerminate' => ( is => 'ro', 
+                                     isa => 'Net::Amazon::EMR::Type::ArrayRefofUnconstrainedStr',
+                                     coerce => 1,
+                                 );
+
 has 'InstanceCount' => ( is => 'ro', 
                          isa => 'Int' );
 
 has 'InstanceGroupId' => ( is => 'ro', 
-                           isa => 'Str' );
+                           isa => 'Net::Amazon::EMR::Type::ConstrainedStr',
+                           coerce => 1,
+                       );
 
 
 __PACKAGE__->meta->make_immutable();
