@@ -2,6 +2,7 @@ package Net::Amazon::EMR::JobFlowExecutionStatusDetail;
 use Moose;
 with 'Net::Amazon::EMR::Role::AttrHash';
 use Net::Amazon::EMR::Coercions;
+use Moose::Util::TypeConstraints;
 
 has 'CreationDateTime' => ( is => 'ro', 
                             isa => 'Net::Amazon::EMR::Type::DateTime',
@@ -14,7 +15,9 @@ has 'EndDateTime' => ( is => 'ro',
     );
 
 has 'LastStateChangeReason' => ( is => 'ro', 
-                                 isa => 'Str' );
+                                 isa => 'Net::Amazon::EMR::Type::LongConstrainedStr',
+                                 coerce => 1,
+                             );
 
 has 'ReadyDateTime' => ( is => 'ro', 
                          isa => 'Net::Amazon::EMR::Type::DateTime',
@@ -26,8 +29,12 @@ has 'StartDateTime' => ( is => 'ro',
                          coerce => 1,
     );
 
-has 'State' => ( is => 'ro', 
-                 isa => 'Str' );
+subtype 'Net::Amazon::EMR::Type::JobFlowExecutionStatusDetail::State' => as 'Str' => where { m/^(?:STARTING | BOOTSTRAPPING | RUNNING | WAITING | SHUTTING_DOWN | TERMINATED | COMPLETED | FAILED)$/x };
+
+has 'State' => ( is => 'ro',
+                 isa => 'Net::Amazon::EMR::Type::JobFlowExecutionStatusDetail::State',
+                 required => 1,
+             );
 
 __PACKAGE__->meta->make_immutable();
 
