@@ -4,16 +4,26 @@ with 'Net::Amazon::EMR::Role::AttrHash';
 use Net::Amazon::EMR::Coercions;
 
 has 'Ec2KeyName' => ( is => 'ro', 
-                      isa => 'Str' );
+                      isa => 'Net::Amazon::EMR::Type::ConstrainedStr',
+                      coerce => 1,
+                  );
 
 has 'Ec2SubnetId' => ( is => 'ro', 
-                       isa => 'Str' );
+                       isa => 'Net::Amazon::EMR::Type::ConstrainedStr',
+                       coerce => 1,
+                   );
+
 
 has 'HadoopVersion' => ( is => 'ro', 
-                         isa => 'Str' );
+                         isa => 'Net::Amazon::EMR::Type::ConstrainedStr',
+                         coerce => 1,
+                     );
+
 
 has 'InstanceCount' => ( is => 'ro', 
-                         isa => 'Int' );
+                         isa => 'Int',
+                         required => 1,
+                     );
 
 has 'InstanceGroups' => ( is => 'ro', 
                           isa => 'Net::Amazon::EMR::Type::ArrayRefofInstanceGroupDetail',
@@ -24,23 +34,33 @@ has 'KeepJobFlowAliveWhenNoSteps' => ( is => 'ro',
                                        coerce => 1 );
 
 has 'MasterInstanceId' => ( is => 'ro', 
-                            isa => 'Str' );
+                            isa => 'Net::Amazon::EMR::Type::ConstrainedStr',
+                            coerce => 1,
+                        );
 
 has 'MasterInstanceType' => ( is => 'ro', 
-                              isa => 'Str' );
+                              isa => 'Net::Amazon::EMR::Type::NonEmptyConstrainedStr',
+                              coerce => 1,
+                              required => 1,
+                          );
 
 has 'MasterPublicDnsName' => ( is => 'ro', 
-                               isa => 'Str' );
+                               isa => 'Net::Amazon::EMR::Type::ConstrainedStr',
+                               coerce => 1,
+                           );
 
 has 'NormalizedInstanceHours' => ( is => 'ro', 
                                    isa => 'Int' );
 
 has 'Placement' => ( is => 'ro', 
-                     isa => 'Net::Amazon::EMR::Type::PlacementType | Undef',
+                     isa => 'Net::Amazon::EMR::Type::PlacementType',
                      coerce => 1  );
 
 has 'SlaveInstanceType' => ( is => 'ro', 
-                             isa => 'Str' );
+                             isa => 'Net::Amazon::EMR::Type::NonEmptyConstrainedStr',
+                             coerce => 1,
+                             required => 1,
+                         );
 
 
 has 'TerminationProtected' => ( is => 'ro', 
