@@ -4,7 +4,10 @@ with 'Net::Amazon::EMR::Role::AttrHash';
 
 
 has 'AvailabilityZone' => ( is => 'ro', 
-                            isa => 'Str' );
+                            isa => 'Net::Amazon::EMR::Type::LongConstrainedStr',
+                            coerce => 1,
+                            required => 1,
+                        );
 
 
 __PACKAGE__->meta->make_immutable();
