@@ -1,13 +1,18 @@
 package Net::Amazon::EMR::ScriptBootstrapActionConfig;
 use Moose;
 with 'Net::Amazon::EMR::Role::AttrHash';
+use Net::Amazon::EMR::Coercions;
 
 has 'Args' => ( is => 'ro', 
-                isa => 'Net::Amazon::EMR::Type::ArrayRefofStr | Undef',
-                coerce => 1);
+                isa => 'Net::Amazon::EMR::Type::ArrayRefofLongConstrainedStr',
+                coerce => 1,
+            );
 
 has 'Path' => ( is => 'ro', 
-                isa => 'Str' );
+                isa => 'Net::Amazon::EMR::Type::LongConstrainedStr',
+                coerce => 1,
+                required => 1,
+            );
 
 
 __PACKAGE__->meta->make_immutable();
