@@ -2,17 +2,25 @@ package Net::Amazon::EMR::StepConfig;
 use Moose;
 with 'Net::Amazon::EMR::Role::AttrHash';
 use Net::Amazon::EMR::Coercions;
+use Moose::Util::TypeConstraints;
 
-has 'ActionOnFailure' => ( is => 'ro', 
-                 isa => 'Str' );
+subtype 'Net::Amazon::EMR::Type::StepConfig::ActionOnFailure' => as 'Str' => where { m/^(?:TERMINATE_JOB_FLOW | TERMINATE_CLUSTER | CANCEL_AND_WAIT | CONTINUE)$/x };
+
+has 'ActionOnFailure' => ( is => 'ro',
+                           isa => 'Net::Amazon::EMR::Type::StepConfig::ActionOnFailure',
+                       );
 
 has 'HadoopJarStep' => ( is => 'ro', 
                          isa => 'Net::Amazon::EMR::Type::HadoopJarStepConfig',
                          coerce => 1,
+                         required => 1,
     );
 
 has 'Name' => ( is => 'ro', 
-                  isa => 'Str' );
+                isa => 'Net::Amazon::EMR::Type::LongConstrainedStr',
+                coerce => 1,
+                required => 1,
+            );
 
 
 __PACKAGE__->meta->make_immutable();
