@@ -2,12 +2,12 @@ package Net::Amazon::EMR::StepStateChangeReason;
 use Moose;
 with 'Net::Amazon::EMR::Role::AttrHash';
 use Net::Amazon::EMR::Coercions;
+use Moose::Util::TypeConstraints;
 
 subtype 'Net::Amazon::EMR::Type::StepStateChangeReason::Code' => as 'Str' => where { m/^(?:NONE)$/x };
 
 has 'Code' => ( is => 'ro',
                 isa => 'Net::Amazon::EMR::Type::StepStateChangeReason::Code',
-                coerce => 1,
 );
 
 has 'Message' => ( is => 'ro', 
