@@ -3,11 +3,14 @@ use Moose;
 with 'Net::Amazon::EMR::Role::AttrHash';
 use Net::Amazon::EMR::Coercions;
 
+use Moose::Util::TypeConstraints;
+use Net::Amazon::EMR::StepStateChangeReason;
+use Net::Amazon::EMR::StepTimeline;
+
 subtype 'Net::Amazon::EMR::Type::StepStatus::State' => as 'Str' => where { m/^(?:PENDING | RUNNING | COMPLETED | CANCELLED | FAILED | INTERRUPTED)$/x };
 
 has 'State' => ( is => 'ro',
                 isa => 'Net::Amazon::EMR::Type::StepStatus::State',
-                coerce => 1,
 );
 
 has 'StateChangeReason' => ( is => 'ro', 
