@@ -2,12 +2,14 @@ package Net::Amazon::EMR::StepSummary;
 use Moose;
 with 'Net::Amazon::EMR::Role::AttrHash';
 use Net::Amazon::EMR::Coercions;
+use Moose::Util::TypeConstraints;
+use Net::Amazon::EMR::HadoopStepConfig;
+use Net::Amazon::EMR::StepStatus;
 
 subtype 'Net::Amazon::EMR::Type::StepSummary::ActionOnFailure' => as 'Str' => where { m/^(?:TERMINATE_JOB_FLOW | TERMINATE_CLUSTER | CANCEL_AND_WAIT | CONTINUE)$/x };
 
 has 'ActionOnFailure' => ( is => 'ro',
                            isa => 'Net::Amazon::EMR::Type::StepSummary::ActionOnFailure',
-                           coerce => 1,
                        );
 
 has 'Config' => ( is => 'ro',
