@@ -13,7 +13,7 @@ has 'EndDateTime' => ( is => 'ro',
                        coerce => 1,
     );
 
-has 'ReadyDateTime' => ( is => 'ro', 
+has 'StartDateTime' => ( is => 'ro', 
                        isa => 'Net::Amazon::EMR::Type::DateTime',
                        coerce => 1,
     );
